.. _pdaes:

================
PDE Collections
================

Contents
========

.. autofunction:: SolMuseum.pde.gas.ngs_pipe

.. autofunction:: SolMuseum.pde.gas.broken_pipe.rupture_pipe

.. autofunction:: SolMuseum.pde.gas.broken_pipe.leakage_pipe

.. autofunction:: SolMuseum.pde.heat.heat_pipe
